PushMessageApi class
DO NOT EDIT THIS FILE. TO ADJUST THIS CLASS, USE PushMessageApiMixin
The final API is constructed by:
- taking the
PushMessageApiBaseclass - applying a mixin
PushMessageApiMixin] (which allows us to inject other convenience functions) The mixin lives outside of the code generator, so it's used to do any manual tweaking - Applying the
SignalingApiMixin, so events automatically propagate
- Inheritance
-
- Object
- Repository<
IPushMessage> - SunnyApi<
IPushMessage> - PushMessageApi
- Implemented types
- Mixed-in types
-
- SignalingApiMixin<
IPushMessage>
- SignalingApiMixin<
Constructors
- PushMessageApi(ApiClient apiClient, ApiRegistry apis)
Properties
Methods
-
clone(
IPushMessage source) → IPushMessage -
Copies values from one entity into another. This clone operation is important because it allows
inherited
-
create(
IPushMessage body) → Future< IPushMessage> -
inherited
-
delete(
String id) → Future< DeleteResponse> -
inherited
-
initialize(
IPushMessage entity) → IPushMessage -
inherited
-
instantiate(
[dynamic json]) → IPushMessage -
inherited
-
keyToId(
MKey? key) → String? -
inherited
-
list(
{double? limit, double? offset}) → Future< MModelList< IPushMessage> > -
inherited
-
load(
String id) → Future< IPushMessage> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
IPushMessage pushMessage) → Future< ISendResponse> -
override
-
takeFrom(
IPushMessage source, IPushMessage target) → void -
Copies all data from
sourceintotarget. Used when you want to maintain a reference totarget, but want to inject new values fromsourceinherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, IPushMessage body) → Future< ChangeResult> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited